import { Override, Animatable, animate, Data } from "framer";

// Animating Opacity
const opacityValue = Animatable(1);

export const AnimateOpacity: Override = props => {
  opacityValue.set(props.opacity); // Setting ‘opacityValue’ to the current value of the frame
  return {
    opacity: opacityValue, // Binding ‘opacityValue’ to the ‘opacity’ property
    onTap() {
      animate(opacityValue, 0.2); // Animating ‘opacityValue’ from its current value to 20%
    }
  };
};

// Animating Scale
const scaleValue = Animatable(1);

export const AnimateScale: Override = () => {
  return {
    scale: scaleValue, // Binding ‘scaleValue’ to the ‘scale’ property
    onTap() {
      scaleValue.set(0.6); // Setting ‘scaleValue’ an initial 60%
      animate.spring(scaleValue, 1); // Animating ‘scaleValue’ from its current value back to 100%
    }
  };
};
// Note: You can scale horizontally or vertically with ‘scaleX’ and ‘scaleY’. (And there's also a ‘scaleZ’.)

// Animating Width
const widthValue = Animatable(0);

export const AnimateWidth: Override = props => {
  widthValue.set(props.width); // Setting ‘widthValue’ to the current value of the frame
  return {
    width: widthValue, // Binding ‘widthValue’ to the ‘width’ property
    onTap() {
      animate.spring(widthValue, widthValue.get() / 2); // Animating ‘widthValue’ to half the current width
    }
  };
};
// Note: • Will animate from the current width to 50% on every tap
//       • Of course you can also animate ‘height’ (‘size’ apparently only exists in Framer Classic)

// Animating Position
const leftValue = Animatable(0);

export const AnimatePosition: Override = props => {
  leftValue.set(props.left); // Setting ‘leftValue’ to the current value of the frame
  return {
    left: leftValue, // Binding ‘leftValue’ to the ‘left’ property
    async onTap() {
      await animate(leftValue, leftValue.get() - 20).finished; // Animating ‘leftValue’ 20 points left of the current value
      animate.spring(leftValue, leftValue.get() + 20); // When the above line finished: Animating ‘leftValue’ back to the right
    }
  };
};

// Animating Rotation
const rotationValue = Animatable(0);

export const AnimateRotation: Override = props => {
  rotationValue.set(props.rotation); // Setting ‘rotationValue’ to the current rotation value of the frame

  return {
    rotation: rotationValue,
    onTap() {
      animate.spring(rotationValue, rotationValue.get() + 45);
    }
  };
};

// Animating Rotation X and Y
// const rotationValue = Animatable(0);

// export const AnimateRotation: Override = props => {
//   rotationValue.set(props.rotation); // Setting ‘rotationValue’ to the current rotation value of the frame

//   return {
//     rotation: rotationValue,
//     onTap() {
//       animate.spring(rotationValue, rotationValue.get() + 90);
//     }
//   };
// };

const colorValue = Animatable("#1199EE");

export const AnimateColor: Override = () => {
  return {
    background: colorValue,
    onTap() {
      animate(colorValue, "red");
    }
  };
};
